@@ -1,10 +1,10 @@
 /***********************************************************
- * RHmm version 0.9.4                                      *
+ * RHmm version 1.0.3                                      *
  *                                                         *
  *                                                         *
  * Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> *
  *                                                         *
- * Date: 2007/11/08                                        *
+ * Date: 2008/06/26                                        *
  *                                                         *
  ***********************************************************/
 #include "cOTError.h"
@@ -12,7 +12,11 @@
 cOTError::cOTError(char *theMess)
 {
 	if (theMess != (char *)NULL) 
-		std::cout << theMess << std::endl ;
-	exit(0) ;
+#ifndef _RDLL_
+		cout << theMess << std::endl ;
+#else
+		Rprintf("%s\n", theMess) ;
+#endif // _RDLL_
+		exit(0) ;
 }
 
