@@ -1,15 +1,17 @@
 /***********************************************************
- * RHmm version 0.9.4                                      *
+ * RHmm version 1.0.3                                      *
  *                                                         *
  *                                                         *
  * Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> *
  *                                                         *
- * Date: 2007/11/08                                        *
+ * Date: 2008/06/26                                        *
  *                                                         *
  ***********************************************************/
 #ifndef _COTVECTOR_H_
 #define _COTVECTOR_H_
-#include <iostream>
+#ifndef _RDLL_
+	#include <iostream>
+#endif //_RDLL_
 #include "cOTError.h"
 
 class cOTMatrix ;
@@ -50,7 +52,9 @@ class cOTVector
 		friend bool operator <=(cOTVector& theVect1, cOTVector& theVect2) ;
 		friend bool operator >(cOTVector& theVect1, cOTVector& theVect2) ;
 		friend bool operator >=(cOTVector& theVect1, cOTVector& theVect2) ;
+#ifndef _RDLL_
 		friend std::ostream& operator <<(std::ostream& theStream, cOTVector &theVect) ;
+#endif // -RDLL_
 		friend cOTMatrix& transpose(cOTVector &theVect) ;
 		friend cOTVector& zeros(uint theN) ;
 		friend cOTVector& copy_double(double* theVect, uint theSize) ;
